@@ -1,11 +1,12 @@
 #' @title Brute-force calculation of an expected permutation matrix
 #' @description Computes an expected permutation matrix and marginal likelihood from a matrix of assignment likelihoods. The function literally enumerates all permutations so will be impractial for matrices with more than 10 rows.
 #' @param A A matrix of assignment likelihoods.
+#' @param return.permanent A logical value indicating whether the function should also return the permanent of \code{A}, which is then added to the output as an attribute.
 #' @return \code{E(P)}, the expected permutation matrix corresponding to \code{A}.
 #' @examples
 #' data(A)
 #' brute(A)
-brute<-function(A){
+brute<-function(A,return.permanent=FALSE){
   n<-nrow(A)
   cnt<-rep(0,n)
   ind<-1:n
@@ -15,15 +16,22 @@ brute<-function(A){
   
   i<-0
   while(i<n){
-    if(cnt[i+1]<i){                                           # The outer parts of this while
-    if(i%%2==0){ind[c(1,i+1)]<-ind[c(i+1,1)]                  # loop implements Heap's algorithm
-    }else{ind[c(i+1,cnt[i+1]+1)]<-ind[c(cnt[i+1]+1,i+1)]}     # for enumerating permutations.
+    
+    # The outer parts of this while
+    # loop implement Heap's algorithm
+    # for enumerating permutations.
+    if(cnt[i+1]<i){                                           
+    if(i%%2==0){ind[c(1,i+1)]<-ind[c(i+1,1)]                  
+    }else{ind[c(i+1,cnt[i+1]+1)]<-ind[c(cnt[i+1]+1,i+1)]}     
     cnt[i+1]<-cnt[i+1]+1
     i<-0
     
-    indmat<-cbind(1:n,ind)    # This part of the code updates
-    w<-prod(A[indmat])        # the running weighted mean of 
-    W<-W+w                    # permutation matrices.
+    # This part of the code updates
+    # the running weighted mean of 
+    # permutation matrices.
+    indmat<-cbind(1:n,ind)    
+    w<-prod(A[indmat])        
+    W<-W+w                    
     EP<-EP*(1-w/W)
     EP[indmat]<-EP[indmat]+w/W
     
@@ -32,6 +40,6 @@ brute<-function(A){
       i<-i+1
     }
   }
-  attr(EP,"permanent")<-W
+  if(return.permanent){attr(EP,"permanent")<-W}
   EP
 }
